<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU" sourcelanguage="en">
<context>
    <name>AbstractWidgetList</name>
    <message>
        <source>Add New</source>
        <translation>Új hozzáadása</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Mozogj feljebb</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Mozgás lefelé</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eltávolítani</translation>
    </message>
</context>
<context>
    <name>AcceptTool</name>
    <message>
        <source>Accept</source>
        <translation>Elfogadom</translation>
    </message>
    <message>
        <source>Accept the capture</source>
        <translation>Fogadja el az elfogást</translation>
    </message>
</context>
<context>
    <name>AppLauncher</name>
    <message>
        <source>App Launcher</source>
        <translation>Alkalmazás indító</translation>
    </message>
    <message>
        <source>Choose an app to open the capture</source>
        <translation>Válassz egy alkalmazást hogy elinduljon a felvétel</translation>
    </message>
</context>
<context>
    <name>AppLauncherWidget</name>
    <message>
        <source>Open With</source>
        <translation>Megnyitás ezzel</translation>
    </message>
    <message>
        <source>Launch in terminal</source>
        <translation>Futtatás terminálban</translation>
    </message>
    <message>
        <source>Keep open after selection</source>
        <translation>Kiválasztás után maradjon nyitva</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Unable to launch in terminal.</source>
        <translation>Nem lehet megnyitni a terminálban.</translation>
    </message>
    <message>
        <source>Unable to write in</source>
        <translation>Nem lehet írni</translation>
    </message>
</context>
<context>
    <name>ArrowTool</name>
    <message>
        <source>Arrow</source>
        <translation>Nyíl</translation>
    </message>
    <message>
        <source>Set the Arrow as the paint tool</source>
        <translation>Beállítja a nyíl eszközt festő eszközként</translation>
    </message>
</context>
<context>
    <name>BlurTool</name>
    <message>
        <source>Blur</source>
        <translation type="vanished">Homályosítás</translation>
    </message>
    <message>
        <source>Set Blur as the paint tool</source>
        <translation type="vanished">Beállítja a Homályosítás eszközt festő eszközként</translation>
    </message>
</context>
<context>
    <name>CaptureLauncher</name>
    <message>
        <source>&lt;b&gt;Capture Mode&lt;/b&gt;</source>
        <translation type="vanished">&lt;b&gt;Rögzítési mód&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Rectangular Region</source>
        <translation>Téglalapos kijelölő</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Teljes Képernyő (Minden Kijelzőn)</translation>
    </message>
    <message>
        <source>No Delay</source>
        <translation>Késleltetés Nélkül</translation>
    </message>
    <message>
        <source> second</source>
        <translation> másodperc</translation>
    </message>
    <message>
        <source> seconds</source>
        <translation> másodperc</translation>
    </message>
    <message>
        <source>Take new screenshot</source>
        <translation>Új képernyőmentés</translation>
    </message>
    <message>
        <source>Area:</source>
        <translation>Terület:</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Késleltetés:</translation>
    </message>
    <message>
        <source>Full Screen (Current Display)</source>
        <translation>Teljes képernyő (Jelenlegi kijelzőn)</translation>
    </message>
    <message>
        <source>Capture Launcher</source>
        <translation>Capture Launcher</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Capture Mode</translation>
    </message>
    <message>
        <source>WxH+x+y</source>
        <translation>WxH+x+y</translation>
    </message>
</context>
<context>
    <name>CaptureWidget</name>
    <message>
        <source>Select an area with the mouse, or press Esc to exit.
Press Enter to capture the screen.
Press Right Click to show the color picker.
Use the Mouse Wheel to change the thickness of your tool.</source>
        <translation type="vanished">Válassz egy területet egérrel, vagy nyomj Esc-et a kilépéshez.
Nyomj entert a felvételhez.
Kattints job egérgombal a szín választásához.
Használd a görgőt az eszköz vastagságának állítására.</translation>
    </message>
    <message>
        <source>Unable to capture screen</source>
        <translation>Nem lehet felvételt készíteni</translation>
    </message>
    <message>
        <source>Select an area with the mouse, or press Esc to exit.
Press Enter to capture the screen.
Press Right Click to show the color picker.
Use the Mouse Wheel to change the thickness of your tool.
Press Space to open the side panel.</source>
        <translation type="vanished">Jelölj ki egy területet az egérrel, vagy lépj ki az Esc billentyűvel.
Nyomj Entert a képernyő rögzítéséhez.
Nyomd meg a Jobb Egérgombot a szín választó megjelenítéséhez.
Használd az egérgörgőt az eszköz vonalvastagságának változtatásáért.
Nyomd meg a Space billentyűt, hogy megnyisd az oldalsó panelt.</translation>
    </message>
    <message>
        <source>Tool Settings</source>
        <translation>Eszközbeállítások</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <source>Select screenshot area</source>
        <translation>Képernyőkép terület kiválasztása</translation>
    </message>
    <message>
        <source>Mouse Wheel</source>
        <translation type="unfinished">Görgő</translation>
    </message>
    <message>
        <source>Change tool size</source>
        <translation>Szerszámméret váltás</translation>
    </message>
    <message>
        <source>Right Click</source>
        <translation type="unfinished">jobb egérgomb</translation>
    </message>
    <message>
        <source>Show color picker</source>
        <translation type="unfinished">Színválasztó mutatása</translation>
    </message>
    <message>
        <source>Open side panel</source>
        <translation>Nyitott oldalfal</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">Bezárás</translation>
    </message>
    <message>
        <source>Flameshot has lost focus. Keyboard shortcuts won&apos;t work until you click somewhere.</source>
        <translation>Flameshot elvesztette a fókuszt. A billentyűparancsok nem működnek, amíg nem kattintasz valahol.</translation>
    </message>
    <message>
        <source>Configuration error resolved. Launch `flameshot gui` again to apply it.</source>
        <translation>Konfigurációs hiba megoldva. Indítsa el újra a `flameshot gui-t` az alkalmazáshoz.</translation>
    </message>
    <message>
        <source>Quit Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to quit capture?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show this again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CircleCountTool</name>
    <message>
        <source>Circle Counter</source>
        <translation>Körös Számláló Eszköz</translation>
    </message>
    <message>
        <source>Add an autoincrementing counter bubble</source>
        <translation>Hozzáad egy buborékban lévő folyamatosan növekvő számot</translation>
    </message>
</context>
<context>
    <name>CircleTool</name>
    <message>
        <source>Circle</source>
        <translation>Kör</translation>
    </message>
    <message>
        <source>Set the Circle as the paint tool</source>
        <translation>Beálítja a Kör eszközt festő eszközként</translation>
    </message>
</context>
<context>
    <name>ColorDialog</name>
    <message>
        <source>Select Color</source>
        <translation>Válasszon színt</translation>
    </message>
    <message>
        <source>Saturation</source>
        <translation>Telítettség</translation>
    </message>
    <message>
        <source>Hue</source>
        <translation>Árnyalat</translation>
    </message>
    <message>
        <source>Hex</source>
        <translation>Hex</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Blue</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Érték</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Green</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Red</translation>
    </message>
</context>
<context>
    <name>ColorGrabWidget</name>
    <message>
        <source>Accept color</source>
        <translation>Szín elfogadása</translation>
    </message>
    <message>
        <source>Precisely select color</source>
        <translation>Precisely select color</translation>
    </message>
    <message>
        <source>Toggle magnifier</source>
        <translation>Toggle magnifier</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Enter or Left Click</source>
        <translation></translation>
    </message>
    <message>
        <source>Hold Left Click</source>
        <translation></translation>
    </message>
    <message>
        <source>Space or Right Click</source>
        <translation></translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="unfinished">Esc</translation>
    </message>
</context>
<context>
    <name>ColorPickerEditor</name>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Press button to delete the selected preset</source>
        <translation>Press button to delete the selected preset</translation>
    </message>
    <message>
        <source>Add Preset:</source>
        <translation>Add Preset:</translation>
    </message>
    <message>
        <source>Enter color manually or select it using the color-wheel</source>
        <translation>Enter color manually or select it using the color-wheel</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Add</translation>
    </message>
    <message>
        <source>Press button to add preset</source>
        <translation>Press button to add preset</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Hiba</translation>
    </message>
    <message>
        <source>Unable to add preset. Maximum limit reached.</source>
        <translation>Unable to add preset. Maximum limit reached.</translation>
    </message>
    <message>
        <source>Unable to remove preset. Minimum limit reached.</source>
        <translation>Unable to remove preset. Minimum limit reached.</translation>
    </message>
    <message>
        <source>Edit Preset:</source>
        <translation>Edit Preset:</translation>
    </message>
    <message>
        <source>Enter color to update preset</source>
        <translation>Enter color to update preset</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished">Frissítés</translation>
    </message>
    <message>
        <source>Press button to update the selected preset</source>
        <translation>Press button to update the selected preset</translation>
    </message>
</context>
<context>
    <name>ConfigErrorDetails</name>
    <message>
        <source>Configuration errors</source>
        <translation>Configuration errors</translation>
    </message>
</context>
<context>
    <name>ConfigHandler</name>
    <message>
        <source>You have successfully resolved the configuration error.</source>
        <translation>You have successfully resolved the configuration error.</translation>
    </message>
    <message>
        <source>Bad config key &apos;%1&apos; in ConfigHandler. Please report this as a bug.</source>
        <translation>Bad config key &apos;%1&apos; in ConfigHandler. Please report this as a bug.</translation>
    </message>
    <message>
        <source>Unrecognized setting: &apos;%1&apos;
</source>
        <translation>Unrecognized setting: &apos;%1&apos;
</translation>
    </message>
    <message>
        <source>Unrecognized shortcut name: &apos;%1&apos;.
</source>
        <translation>Unrecognized shortcut name: &apos;%1&apos;.
</translation>
    </message>
    <message>
        <source>Shortcut conflict: &apos;%1&apos; and &apos;%2&apos; have the same shortcut: %3
</source>
        <translation>Shortcut conflict: &apos;%1&apos; and &apos;%2&apos; have the same shortcut: %3
</translation>
    </message>
    <message>
        <source>Bad value in &apos;%1&apos;. Expected: %2
</source>
        <translation>Bad value in &apos;%1&apos;. Expected: %2
</translation>
    </message>
    <message>
        <source>The configuration contains an error. Open configuration to resolve.</source>
        <translation>The configuration contains an error. Open configuration to resolve.</translation>
    </message>
</context>
<context>
    <name>ConfigResolver</name>
    <message>
        <source>Resolve configuration errors</source>
        <translation>Resolve configuration errors</translation>
    </message>
    <message>
        <source>&lt;b&gt;You must resolve all errors before continuing:&lt;/b&gt;</source>
        <translation>&lt;b&gt;You must resolve all errors before continuing:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished">Visszaállítás</translation>
    </message>
    <message>
        <source>Reset to the default value.</source>
        <translation>Reset to the default value.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Eltávolítani</translation>
    </message>
    <message>
        <source>Remove this setting.</source>
        <translation>Remove this setting.</translation>
    </message>
    <message>
        <source>Some keyboard shortcuts have conflicts.
This will NOT prevent flameshot from starting.
Please solve them manually in the configuration file.</source>
        <translation>Some keyboard shortcuts have conflicts.
This will NOT prevent flameshot from starting.
Please solve them manually in the configuration file.</translation>
    </message>
    <message>
        <source>Resolve all</source>
        <translation>Resolve all</translation>
    </message>
    <message>
        <source>Resolve all listed errors.</source>
        <translation>Resolve all listed errors.</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>ConfigWindow</name>
    <message>
        <source>Configuration</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Kezelőfelület</translation>
    </message>
    <message>
        <source>Filename Editor</source>
        <translation>Fájlnév szerkesztő</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <source>&lt;b&gt;Configuration file has errors. Resolve them before continuing.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Configuration file has errors. Resolve them before continuing.&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Resolve</source>
        <translation>Resolve</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <source>&amp;Configuration</source>
        <translation type="vanished">&amp;Konfiguráció</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="vanished">&amp;Információ</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="vanished">&amp;Bezárás</translation>
    </message>
    <message>
        <source>&amp;Take Screenshot</source>
        <translation type="vanished">&amp;Képernyő Mentés Készítése</translation>
    </message>
    <message>
        <source>&amp;Open Launcher</source>
        <translation type="vanished">&amp;Alkalmazásindító Megnyitása</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="vanished">&amp;Rólunk</translation>
    </message>
    <message>
        <source>&amp;Latest Uploads</source>
        <translation type="vanished">&amp;Eddigi Feltöltések</translation>
    </message>
    <message>
        <source>New version %1 is available</source>
        <translation type="vanished">Elérhető az új %1 verzió</translation>
    </message>
    <message>
        <source>You have the latest version</source>
        <translation type="vanished">A legfrisebb verzió van feltelepítve</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation type="vanished">Frissítések keresése</translation>
    </message>
    <message>
        <source>Failed to get information about the latest version.</source>
        <translation type="vanished">Nem sikerült információt szerezni a legújabb verzióról.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Hiba</translation>
    </message>
    <message>
        <source>Unable to close active modal widgets</source>
        <translation type="vanished">Nem sikerült bezárni az aktív widgeteket</translation>
    </message>
    <message>
        <source>URL copied to clipboard.</source>
        <translation type="obsolete">URL másolva a vágólapra.</translation>
    </message>
</context>
<context>
    <name>CopyTool</name>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Copies the selecion into the clipboard</source>
        <translation type="vanished">Másolja a kiválasztott területet</translation>
    </message>
    <message>
        <source>Copy the selection into the clipboard</source>
        <translation type="vanished">Vágolapra másolja a kijelölt területet</translation>
    </message>
    <message>
        <source>Copy selection to clipboard</source>
        <translation>Copy selection to clipboard</translation>
    </message>
</context>
<context>
    <name>DBusUtils</name>
    <message>
        <source>Unable to connect via DBus</source>
        <translation type="vanished">Nem lehet csatlakozni DBus-al</translation>
    </message>
</context>
<context>
    <name>ExitTool</name>
    <message>
        <source>Exit</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>Leave the capture screen</source>
        <translation>Bezárja a felvevőt</translation>
    </message>
</context>
<context>
    <name>FileNameEditor</name>
    <message>
        <source>Edit the name of your captures:</source>
        <translation>Felvételek neveinek szerkesztése:</translation>
    </message>
    <message>
        <source>Edit:</source>
        <translation>Szerkesztés:</translation>
    </message>
    <message>
        <source>Preview:</source>
        <translation>Előnézet:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Saves the pattern</source>
        <translation>Minta mentése</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="vanished">Visszaállítás</translation>
    </message>
    <message>
        <source>Restores the saved pattern</source>
        <translation>Visszaállítja a mentett mintát</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Deletes the name</source>
        <translation>Törli a nevet</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restore</translation>
    </message>
</context>
<context>
    <name>FileNameHandler</name>
    <message>
        <source>screenshot</source>
        <translation type="vanished">Képernyőmentés</translation>
    </message>
</context>
<context>
    <name>Flameshot</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Hiba</translation>
    </message>
    <message>
        <source>Unable to close active modal widgets</source>
        <translation type="unfinished">Nem sikerült bezárni az aktív widgeteket</translation>
    </message>
    <message>
        <source>URL copied to clipboard.</source>
        <translation type="unfinished">URL másolva a vágólapra.</translation>
    </message>
</context>
<context>
    <name>FlameshotDBusAdapter</name>
    <message>
        <source>Unable to capture screen</source>
        <translation type="vanished">Nem lehet képernyőképet készíteni</translation>
    </message>
</context>
<context>
    <name>FlameshotDaemon</name>
    <message>
        <source>Unable to connect via DBus</source>
        <translation>Unable to connect via DBus</translation>
    </message>
    <message>
        <source>New version %1 is available</source>
        <translation type="unfinished">Elérhető az új %1 verzió</translation>
    </message>
    <message>
        <source>You have the latest version</source>
        <translation type="unfinished">A legfrisebb verzió van feltelepítve</translation>
    </message>
    <message>
        <source>Failed to get information about the latest version.</source>
        <translation type="unfinished">Nem sikerült információt szerezni a legújabb verzióról.</translation>
    </message>
</context>
<context>
    <name>GeneneralConf</name>
    <message>
        <source>Show help message</source>
        <translation type="vanished">Mutassa a segítséget</translation>
    </message>
    <message>
        <source>Show the help message at the beginning in the capture mode.</source>
        <translation type="vanished">Mutassa a segítséget a felvevő mód kezdetekor.</translation>
    </message>
    <message>
        <source>Show desktop notifications</source>
        <translation type="vanished">Mutassa az asztali üzeneteket</translation>
    </message>
    <message>
        <source>Show tray icon</source>
        <translation type="vanished">Tray ikon mutatása</translation>
    </message>
    <message>
        <source>Show the systemtray icon</source>
        <translation type="vanished">Systemtray ikon mutatása</translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="vanished">Importálás</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Hiba</translation>
    </message>
    <message>
        <source>Unable to read file.</source>
        <translation type="vanished">Nem lehet olvasni a fájlt.</translation>
    </message>
    <message>
        <source>Unable to write file.</source>
        <translation type="vanished">Nem lehet írni a fájlt.</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation type="vanished">Fájl mentése</translation>
    </message>
    <message>
        <source>Confirm Reset</source>
        <translation type="vanished">Visszaállítás elfogadása</translation>
    </message>
    <message>
        <source>Are you sure you want to reset the configuration?</source>
        <translation type="vanished">Biztos vagy benne hogy viszaállítod a beállításokat?</translation>
    </message>
    <message>
        <source>Configuration File</source>
        <translation type="vanished">Konfigurációs fájl</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Export</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="vanished">Visszaállítás</translation>
    </message>
    <message>
        <source>Launch at startup</source>
        <translation type="vanished">Indítás rendszerinduláskor</translation>
    </message>
    <message>
        <source>Launch Flameshot</source>
        <translation type="vanished">Flameshot indítása</translation>
    </message>
</context>
<context>
    <name>GeneralConf</name>
    <message>
        <source>Import</source>
        <translation>Importálás</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Unable to read file.</source>
        <translation>Nem lehet olvasni a fájlt.</translation>
    </message>
    <message>
        <source>Unable to write file.</source>
        <translation>Nem lehet írni a fájlt.</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <source>Confirm Reset</source>
        <translation>Visszaállítás elfogadása</translation>
    </message>
    <message>
        <source>Are you sure you want to reset the configuration?</source>
        <translation>Biztos vagy benne hogy viszaállítod a beállításokat?</translation>
    </message>
    <message>
        <source>Show help message</source>
        <translation>Súgó üzenet mutatása</translation>
    </message>
    <message>
        <source>Show the help message at the beginning in the capture mode.</source>
        <translation type="vanished">Súgó üzenet mutatása rögzítő mód kezdetekor.</translation>
    </message>
    <message>
        <source>Show the side panel button</source>
        <translation>Oldalsó panel nyitó gomb mutatása</translation>
    </message>
    <message>
        <source>Show the side panel toggle button in the capture mode.</source>
        <translation type="vanished">Oldalsó panel nyitó gomb megjelenítése rögzítő módban.</translation>
    </message>
    <message>
        <source>Show desktop notifications</source>
        <translation>Asztali értesítések megjelenítése</translation>
    </message>
    <message>
        <source>Show tray icon</source>
        <translation>Ikon megjelenítése a tálcán</translation>
    </message>
    <message>
        <source>Show the systemtray icon</source>
        <translation type="vanished">Ikon megjelenítése a tálcán</translation>
    </message>
    <message>
        <source>Confirmation required to delete screenshot from the latest uploads</source>
        <translation>Legutóbb feltöltött képek közül törléskor kérjen megerősítést</translation>
    </message>
    <message>
        <source>Configuration File</source>
        <translation>Konfigurációs fájl</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Visszaállítás</translation>
    </message>
    <message>
        <source>Automatic check for updates</source>
        <translation>Frissítések automatikus keresése</translation>
    </message>
    <message>
        <source>Launch at startup</source>
        <translation type="vanished">Indítás rendszerinduláskor</translation>
    </message>
    <message>
        <source>Launch Flameshot</source>
        <translation type="vanished">Flameshot indítása</translation>
    </message>
    <message>
        <source>Show welcome message on launch</source>
        <translation>Üdvözlő üzenet mutatása indításkor</translation>
    </message>
    <message>
        <source>Copy URL after upload</source>
        <translation>URL vágolapra másolása feltöltés után</translation>
    </message>
    <message>
        <source>Copy URL and close window after upload</source>
        <translation type="vanished">URL vágolapra másolása és ablak bezárása feltöltés után</translation>
    </message>
    <message>
        <source>Save image after copy</source>
        <translation>Másolás után kép mentése</translation>
    </message>
    <message>
        <source>Save image file after copying it</source>
        <translation type="vanished">Fénykép elmentése másolás után</translation>
    </message>
    <message>
        <source>Save Path</source>
        <translation>Mentés helye</translation>
    </message>
    <message>
        <source>Change...</source>
        <translation>Változtatás...</translation>
    </message>
    <message>
        <source>Use fixed path for screenshots to save</source>
        <translation>Fix elérési útvonal használata a képernyőmentésekhez</translation>
    </message>
    <message>
        <source>Copy file path after save</source>
        <translation>Mentés után elérési útvonal másolása</translation>
    </message>
    <message>
        <source>Choose a Folder</source>
        <translation>Válassz egy Mappát</translation>
    </message>
    <message>
        <source>Unable to write to directory.</source>
        <translation>Nem lehet menteni ebbe a mappába.</translation>
    </message>
    <message>
        <source>Use JPG format for clipboard (PNG default)</source>
        <translation>JPG formátum használata vágolapra másoláskor (PNG az alapértelmezett)</translation>
    </message>
    <message>
        <source>Latest Uploads Max Size</source>
        <translation>Latest Uploads Max Size</translation>
    </message>
    <message>
        <source>Undo limit</source>
        <translation>Undo limit</translation>
    </message>
    <message>
        <source>Allow multiple flameshot GUI instances simultaneously</source>
        <translation>Allow multiple flameshot GUI instances simultaneously</translation>
    </message>
    <message>
        <source>Automatically close daemon when it is not needed</source>
        <translation type="vanished">Automatically close daemon when it is not needed</translation>
    </message>
    <message>
        <source>Use large predefined color palette</source>
        <translation>Use large predefined color palette</translation>
    </message>
    <message>
        <source>Preferred save file extension:</source>
        <translation>Preferred save file extension:</translation>
    </message>
    <message>
        <source>Anti-aliasing image when zoom the pinned image</source>
        <translation>Anti-aliasing image when zoom the pinned image</translation>
    </message>
    <message>
        <source>After zooming the pinned image, should the image get smoothened or stay pixelated</source>
        <translation>After zooming the pinned image, should the image get smoothened or stay pixelated</translation>
    </message>
    <message>
        <source>Upload image without confirmation</source>
        <translation>Upload image without confirmation</translation>
    </message>
    <message>
        <source>Show the help message at the beginning in the capture mode</source>
        <translation>Show the help message at the beginning in the capture mode</translation>
    </message>
    <message>
        <source>Show the side panel toggle button in the capture mode</source>
        <translation>Show the side panel toggle button in the capture mode</translation>
    </message>
    <message>
        <source>Enable desktop notifications</source>
        <translation>Enable desktop notifications</translation>
    </message>
    <message>
        <source>Show icon in the system tray</source>
        <translation>Show icon in the system tray</translation>
    </message>
    <message>
        <source>Ask for confirmation to delete screenshot from the latest uploads</source>
        <translation>Ask for confirmation to delete screenshot from the latest uploads</translation>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation>Check for updates automatically</translation>
    </message>
    <message>
        <source>This allows you to take screenshots of Flameshot itself for example</source>
        <translation>This allows you to take screenshots of Flameshot itself for example</translation>
    </message>
    <message>
        <source>Launch Flameshot daemon when computer is booted</source>
        <translation type="vanished">Launch Flameshot daemon when computer is booted</translation>
    </message>
    <message>
        <source>Show the welcome message box in the middle of the screen while taking a screenshot</source>
        <translation>Show the welcome message box in the middle of the screen while taking a screenshot</translation>
    </message>
    <message>
        <source>Use a large predefined color palette</source>
        <translation>Use a large predefined color palette</translation>
    </message>
    <message>
        <source>Copy URL and close window after uploading was successful</source>
        <translation type="vanished">Copy URL and close window after uploading was successful</translation>
    </message>
    <message>
        <source>After copying the screenshot, save it to a file as well</source>
        <translation>After copying the screenshot, save it to a file as well</translation>
    </message>
    <message>
        <source>Copy the file path to clipboard after the file is saved</source>
        <translation>Copy the file path to clipboard after the file is saved</translation>
    </message>
    <message>
        <source>Show magnifier</source>
        <translation>Show magnifier</translation>
    </message>
    <message>
        <source>Enable a magnifier while selecting the screenshot area</source>
        <translation>Enable a magnifier while selecting the screenshot area</translation>
    </message>
    <message>
        <source>Square shaped magnifier</source>
        <translation>Square shaped magnifier</translation>
    </message>
    <message>
        <source>Make the magnifier to be square-shaped</source>
        <translation>Make the magnifier to be square-shaped</translation>
    </message>
    <message>
        <source>Use last region for GUI mode</source>
        <translation type="unfinished">Use last region for GUI mode</translation>
    </message>
    <message>
        <source>Use the last region as the default selection for the next screenshot in GUI mode</source>
        <translation type="unfinished">Use the last region as the default selection for the next screenshot in GUI mode</translation>
    </message>
    <message>
        <source>Copy on double click</source>
        <translation>Copy on double click</translation>
    </message>
    <message>
        <source>Enable Copy on Double Click</source>
        <translation type="vanished">Enable Copy on Double Click</translation>
    </message>
    <message>
        <source>Imgur Application Client ID</source>
        <translation>Imgur Application Client ID</translation>
    </message>
    <message>
        <source>Show abort notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable abort notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use grim to capture screenshots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grim is a wayland only utility to capture screens based on the screencopy protocol. Generally only enable on minimal wayland window managers like sway, hyprland, etc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically unload from memory when it is not needed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically close daemon (background process) when it is not needed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Launch in background at startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Launch Flameshot daemon (background process) when computer is booted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ask before quit capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show the confirmation prompt before ESC quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Copy to clipboard on Double Click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy URL after uploading was successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use lossy JPG format for clipboard (lossless PNG default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Milliseconds before geometry display hides; 0 means do not hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set geometry display timeout (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selection Geometry Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality range of 0-100; Higher number is better quality and larger file size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>JPEG Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reverse arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw the arrow head first</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryWidget</name>
    <message>
        <source>Latest Uploads</source>
        <translation type="vanished">Korábbi Feltöltések</translation>
    </message>
    <message>
        <source>Screenshots history is empty</source>
        <translation type="vanished">Nincs korábbi képernyőmentésed</translation>
    </message>
    <message>
        <source>Copy URL</source>
        <translation type="vanished">URL másolása</translation>
    </message>
    <message>
        <source>URL copied to clipboard.</source>
        <translation type="vanished">URL másolva a vágólapra.</translation>
    </message>
    <message>
        <source>Open in browser</source>
        <translation type="vanished">Megnyitás böngészőben</translation>
    </message>
    <message>
        <source>Confirm to delete</source>
        <translation type="vanished">Törlés megerősítése</translation>
    </message>
    <message>
        <source>Are you sure you want to delete a screenshot from the latest uploads and server?</source>
        <translation type="vanished">Biztosan törölni szeretnéd a képernyőmentést a korábbi feltöltések közül és a szerverről is?</translation>
    </message>
</context>
<context>
    <name>ImgS3Uploader</name>
    <message>
        <source>Uploading Image</source>
        <translation type="obsolete">Kép feltöltése</translation>
    </message>
    <message>
        <source>URL copied to clipboard.</source>
        <translation type="obsolete">URL másolva a vágólapra.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Hiba</translation>
    </message>
</context>
<context>
    <name>ImgUploadDialog</name>
    <message>
        <source>Upload Confirmation</source>
        <translation>Upload Confirmation</translation>
    </message>
    <message>
        <source>Do you want to upload this capture?</source>
        <translation>Do you want to upload this capture?</translation>
    </message>
    <message>
        <source>Upload without confirmation</source>
        <translation>Upload without confirmation</translation>
    </message>
</context>
<context>
    <name>ImgUploader</name>
    <message>
        <source>Uploading Image</source>
        <translation type="obsolete">Kép feltöltése</translation>
    </message>
    <message>
        <source>Unable to open the URL.</source>
        <translation type="obsolete">Nem lehet az URL-t megnyitni.</translation>
    </message>
    <message>
        <source>URL copied to clipboard.</source>
        <translation type="obsolete">URL másolva a vágólapra.</translation>
    </message>
    <message>
        <source>Screenshot copied to clipboard.</source>
        <translation type="obsolete">Képernyőmentés másolva a vágólapra.</translation>
    </message>
    <message>
        <source>Copy URL</source>
        <translation type="obsolete">URL másolása</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation type="obsolete">URL megnyitása</translation>
    </message>
    <message>
        <source>Image to Clipboard.</source>
        <translation type="obsolete">Kép a vágolapra.</translation>
    </message>
    <message>
        <source>Delete image</source>
        <translation type="obsolete">Kép törlése</translation>
    </message>
</context>
<context>
    <name>ImgUploaderBase</name>
    <message>
        <source>Upload image</source>
        <translation>Upload image</translation>
    </message>
    <message>
        <source>Uploading Image</source>
        <translation type="unfinished">Kép feltöltése</translation>
    </message>
    <message>
        <source>Copy URL</source>
        <translation type="unfinished">URL másolása</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation type="unfinished">URL megnyitása</translation>
    </message>
    <message>
        <source>Delete image</source>
        <translation type="unfinished">Kép törlése</translation>
    </message>
    <message>
        <source>Image to Clipboard.</source>
        <translation>Image to Clipboard.</translation>
    </message>
    <message>
        <source>Unable to open the URL.</source>
        <translation>Unable to open the URL.</translation>
    </message>
    <message>
        <source>URL copied to clipboard.</source>
        <translation type="unfinished">URL másolva a vágólapra.</translation>
    </message>
    <message>
        <source>Screenshot copied to clipboard.</source>
        <translation type="unfinished">Képernyőmentés másolva a vágólapra.</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Save image</translation>
    </message>
    <message>
        <source>Unable to save the screenshot to disk.</source>
        <translation>Unable to save the screenshot to disk.</translation>
    </message>
    <message>
        <source>Screenshot saved.</source>
        <translation>Screenshot saved.</translation>
    </message>
</context>
<context>
    <name>ImgUploaderTool</name>
    <message>
        <source>Image Uploader</source>
        <translation type="unfinished">Kép Feltöltő</translation>
    </message>
    <message>
        <source>Upload the selection</source>
        <translation>Upload the selection</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to Imgur</source>
        <translation type="vanished">Feltöltés Imgur -ra</translation>
    </message>
    <message>
        <source>Uploading Image</source>
        <translation type="vanished">Kép feltöltése</translation>
    </message>
    <message>
        <source>Copy URL</source>
        <translation type="vanished">URL másolása</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation type="vanished">URL megnyitása</translation>
    </message>
    <message>
        <source>Image to Clipboard.</source>
        <translation type="vanished">Kép másolása a Vágolapra.</translation>
    </message>
    <message>
        <source>Unable to open the URL.</source>
        <translation>Nem lehet megnyitni az URL-t.</translation>
    </message>
    <message>
        <source>URL copied to clipboard.</source>
        <translation type="vanished">URL másolva a vágólapra.</translation>
    </message>
    <message>
        <source>Screenshot copied to clipboard.</source>
        <translation type="vanished">Képernyőmentés másolva a vágólapra.</translation>
    </message>
    <message>
        <source>Delete image</source>
        <translation type="vanished">Kép törlése</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderTool</name>
    <message>
        <source>Image Uploader</source>
        <translation type="vanished">Kép Feltöltő</translation>
    </message>
    <message>
        <source>Upload the selection to Imgur</source>
        <translation type="vanished">Feltölti a kiválasztott képet az Imgur -ra</translation>
    </message>
</context>
<context>
    <name>InfoWindow</name>
    <message>
        <source>About</source>
        <translation>Rólunk</translation>
    </message>
    <message>
        <source>Right Click</source>
        <translation type="vanished">jobb egérgomb</translation>
    </message>
    <message>
        <source>Mouse Wheel</source>
        <translation type="vanished">Görgő</translation>
    </message>
    <message>
        <source>Move selection 1px</source>
        <translation type="vanished">Kijelölés mozgatása 1px</translation>
    </message>
    <message>
        <source>Resize selection 1px</source>
        <translation type="vanished">Kijelölés méretezése 1 px</translation>
    </message>
    <message>
        <source>Quit capture</source>
        <translation type="vanished">Felvétel bezárása</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="vanished">Másolás vágólapra</translation>
    </message>
    <message>
        <source>Save selection as a file</source>
        <translation type="vanished">Kijelölés mentése fájlba</translation>
    </message>
    <message>
        <source>Undo the last modification</source>
        <translation type="vanished">Utolsó módosítás visszavonása</translation>
    </message>
    <message>
        <source>Show color picker</source>
        <translation type="vanished">Színválasztó mutatása</translation>
    </message>
    <message>
        <source>Change the tool&apos;s thickness</source>
        <translation type="vanished">Vastagság állítása</translation>
    </message>
    <message>
        <source>Key</source>
        <translation type="vanished">Kulcs</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">Leírás</translation>
    </message>
    <message>
        <source>&lt;u&gt;&lt;b&gt;License&lt;/b&gt;&lt;/u&gt;</source>
        <translation type="vanished">&lt;u&gt;&lt;b&gt;Licensz&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <source>&lt;u&gt;&lt;b&gt;Version&lt;/b&gt;&lt;/u&gt;</source>
        <translation type="vanished">&lt;u&gt;&lt;b&gt;Verzió&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <source>&lt;u&gt;&lt;b&gt;Shortcuts&lt;/b&gt;&lt;/u&gt;</source>
        <translation type="vanished">&lt;u&gt;&lt;b&gt;Gyorsbillentyűk&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <source>Available shortcuts in the screen capture mode.</source>
        <translation type="vanished">Elérhető gyorsbillentyűk a képernyőfelvétel módban.</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Icon</translation>
    </message>
    <message>
        <source>License</source>
        <translation>License</translation>
    </message>
    <message>
        <source>GPLv3+</source>
        <translation>GPLv3+</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Flameshot v</source>
        <translation>Flameshot v</translation>
    </message>
    <message>
        <source>OS Info</source>
        <translation>OS Info</translation>
    </message>
    <message>
        <source>Copy Info</source>
        <translation>Copy Info</translation>
    </message>
</context>
<context>
    <name>InvertTool</name>
    <message>
        <source>Invert</source>
        <translation>Invert</translation>
    </message>
    <message>
        <source>Set Inverter as the paint tool</source>
        <translation>Set Inverter as the paint tool</translation>
    </message>
</context>
<context>
    <name>LineTool</name>
    <message>
        <source>Line</source>
        <translation>Vonal</translation>
    </message>
    <message>
        <source>Set the Line as the paint tool</source>
        <translation>Vonal festőeszköz kiválasztása</translation>
    </message>
</context>
<context>
    <name>MarkerTool</name>
    <message>
        <source>Marker</source>
        <translation>Kijelölő</translation>
    </message>
    <message>
        <source>Set the Marker as the paint tool</source>
        <translation>Kijelőlő festőeszköz kiválaszása</translation>
    </message>
</context>
<context>
    <name>MoveTool</name>
    <message>
        <source>Move</source>
        <translation>Mozgatás eszköz</translation>
    </message>
    <message>
        <source>Move the selection area</source>
        <translation>Mozgatja a kiválasztott területet</translation>
    </message>
</context>
<context>
    <name>PencilTool</name>
    <message>
        <source>Pencil</source>
        <translation>Ceruza</translation>
    </message>
    <message>
        <source>Set the Pencil as the paint tool</source>
        <translation>Ceruza festőeszköz kiválaszása</translation>
    </message>
</context>
<context>
    <name>PinTool</name>
    <message>
        <source>Pin Tool</source>
        <translation>Gombostű Eszköz</translation>
    </message>
    <message>
        <source>Pin image on the desktop</source>
        <translation>Előtérben tartja a képet</translation>
    </message>
</context>
<context>
    <name>PinWidget</name>
    <message>
        <source>Context menu</source>
        <translation>Context menu</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="unfinished">Másolás vágólapra</translation>
    </message>
    <message>
        <source>Save to file</source>
        <translation>Save to file</translation>
    </message>
    <message>
        <source>Rotate Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase Opacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease Opacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">Bezárás</translation>
    </message>
</context>
<context>
    <name>PixelateTool</name>
    <message>
        <source>Pixelate</source>
        <translation>Homályosítás</translation>
    </message>
    <message>
        <source>Set Pixelate as the paint tool</source>
        <translation type="vanished">Homályosító festőeszköz kiválasztása</translation>
    </message>
    <message>
        <source>Set Pixelate as the paint tool.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QHotkey</name>
    <message>
        <source>Failed to register %1. Error: %2</source>
        <translation type="vanished">Nem sikerült %1 rögzítése. %2 Hiba</translation>
    </message>
    <message>
        <source>Failed to unregister %1. Error: %2</source>
        <translation type="vanished">Sikertelen rögzítés törlés %1 -nél. %2 Hiba</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Save Error</source>
        <translation>Mentési hiba</translation>
    </message>
    <message>
        <source>Capture saved as </source>
        <translatorcomment>It is hard to esxpress such stence in hungary eg. Capture saved as JPG  in hungary : A felvétel JPG -ben mentve lett. (Better solution using expressions in string like: Capture saved as %s )</translatorcomment>
        <translation>Felvétel mentve itt: </translation>
    </message>
    <message>
        <source>Error trying to save as </source>
        <translation>Hiba a mentésnél </translation>
    </message>
    <message>
        <source>Unable to connect via DBus</source>
        <translation>Nem lehet D-Bus -on keresztül csatlakozni</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Unable to write in</source>
        <translation>Nem írni</translation>
    </message>
    <message>
        <source>Capture saved to clipboard</source>
        <translation type="vanished">Felvétel mentve a vágólapra</translation>
    </message>
    <message>
        <source>URL copied to clipboard.</source>
        <translation type="vanished">URL másolva a vágólapra.</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciók</translation>
    </message>
    <message>
        <source>Arguments</source>
        <translation type="vanished">Feltételek</translation>
    </message>
    <message>
        <source>arguments</source>
        <translation type="vanished">feltételek</translation>
    </message>
    <message>
        <source>Usage</source>
        <translation>Használat</translation>
    </message>
    <message>
        <source>options</source>
        <translation>opciók</translation>
    </message>
    <message>
        <source>Powerful yet simple to use screenshot software.</source>
        <translation>Multifunkcionális, könnyen használható képernyőmentő szotver.</translation>
    </message>
    <message>
        <source>See</source>
        <translation>Megnézés</translation>
    </message>
    <message>
        <source>Capture the entire desktop.</source>
        <translation type="vanished">Teljes kijelző rögzítése.</translation>
    </message>
    <message>
        <source>Open the capture launcher.</source>
        <translation>Rögzítésindító megnyitása.</translation>
    </message>
    <message>
        <source>Start a manual capture in GUI mode.</source>
        <translation>Manuális rögzítés indítása GUI módban.</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Konfiguráció</translation>
    </message>
    <message>
        <source>Capture a single screen.</source>
        <translation type="vanished">Egy kijelző rögzítése.</translation>
    </message>
    <message>
        <source>Path where the capture will be saved</source>
        <translation type="vanished">Rögzítés mentési helye</translation>
    </message>
    <message>
        <source>Save the capture to the clipboard</source>
        <translation>Rögzítés másolása a vágólapra</translation>
    </message>
    <message>
        <source>Delay time in milliseconds</source>
        <translation>Késleltetési idő milliszekundumban</translation>
    </message>
    <message>
        <source>Set the filename pattern</source>
        <translation>Fájlnév minta megadása</translation>
    </message>
    <message>
        <source>Enable or disable the trayicon</source>
        <translation>Tálca ikon be- és kikapcsolása</translation>
    </message>
    <message>
        <source>Enable or disable run at startup</source>
        <translation>Indítás rendszerinduláskor be- és kikapcsolása</translation>
    </message>
    <message>
        <source>Show the help message in the capture mode</source>
        <translation>Súgó szöveg mutatása rögzítő módban</translation>
    </message>
    <message>
        <source>Define the main UI color</source>
        <translation>Kezelőfelület fő színének beállítása</translation>
    </message>
    <message>
        <source>Define the contrast UI color</source>
        <translation>Kezelőfelület kiemelő színének beállítása</translation>
    </message>
    <message>
        <source>Print raw PNG capture</source>
        <translation>Rögzítés nyomtatása PNG -ből</translation>
    </message>
    <message>
        <source>Define the screen to capture</source>
        <translation type="vanished">Rögzítési képernyő megadása</translation>
    </message>
    <message>
        <source>default: screen containing the cursor</source>
        <translation>alapértelmezett: a kijelző amin a kurzor is elhelyezkedik</translation>
    </message>
    <message>
        <source>Screen number</source>
        <translation>Kijelző száma</translation>
    </message>
    <message>
        <source>Invalid color, this flag supports the following formats:
- #RGB (each of R, G, and B is a single hex digit)
- #RRGGBB
- #RRRGGGBBB
- #RRRRGGGGBBBB
- Named colors like &apos;blue&apos; or &apos;red&apos;
You may need to escape the &apos;#&apos; sign as in &apos;\#FFF&apos;</source>
        <translation>Érvénytelen szín, ez az opció a következő formátumokat támogatja:
- #RGB (egyjegyű hexadecimális értékek)
- #RRGGBB
- #RRRGGGBBB
- #RRRRGGGGBBBB
- Elnevezett színek, mint &apos;blue&apos; vagy &apos;red&apos;
Lehet, hogy meg kepp adnod egy &apos;\&apos; karaktert a &apos;#&apos; karakter előtt például: &apos;\#FFF&apos;</translation>
    </message>
    <message>
        <source>Invalid delay, it must be higher than 0</source>
        <translation type="vanished">Érvénytelen késleltetés, 0-nál nagyobb értéknel kell lennie</translation>
    </message>
    <message>
        <source>Invalid screen number, it must be non negative</source>
        <translation>Érvénytelen kijelző szám, nem lehet negatív</translation>
    </message>
    <message>
        <source>Invalid path, it must be a real path in the system</source>
        <translation type="vanished">Érvénytelen elérési útvonal, nincs ilyen elérési útvonal ezen az eszközön</translation>
    </message>
    <message>
        <source>Invalid value, it must be defined as &apos;true&apos; or &apos;false&apos;</source>
        <translation>Érvénytelen érték, lehetséges értékek a &apos;true&apos; és a &apos;false&apos;</translation>
    </message>
    <message>
        <source>Capture saved to clipboard.</source>
        <translation>Rögzítés másolva a vágólapra.</translation>
    </message>
    <message>
        <source>Hello, I&apos;m here! Click icon in the tray to take a screenshot or click with a right button to see more options.</source>
        <translation>Heló, Itt vagyok! Kattints a tálca ikonra, hogy képernyőmentést készíts vagy kattints jobb egérgombbal a további lehetőségekért.</translation>
    </message>
    <message>
        <source>Toggle side panel</source>
        <translation type="vanished">Oldalsó panel ki- és bekapcsolása</translation>
    </message>
    <message>
        <source>Resize selection left 1px</source>
        <translation type="vanished">Kijelölés átméretezése balra 1px-el</translation>
    </message>
    <message>
        <source>Resize selection right 1px</source>
        <translation type="vanished">Kijelölés átméretezése jobbra 1px-el</translation>
    </message>
    <message>
        <source>Resize selection up 1px</source>
        <translation type="vanished">Kijelölés átméretezése fel 1px-el</translation>
    </message>
    <message>
        <source>Resize selection down 1px</source>
        <translation type="vanished">Kijelölés átméretezése le 1px-el</translation>
    </message>
    <message>
        <source>Move selection left 1px</source>
        <translation type="vanished">Kijelölés mozgatása balra 1px-el</translation>
    </message>
    <message>
        <source>Move selection right 1px</source>
        <translation type="vanished">Kijelölés mozgatása jobbra 1px-el</translation>
    </message>
    <message>
        <source>Move selection up 1px</source>
        <translation type="vanished">Kijelölés mozgatása fel 1px-el</translation>
    </message>
    <message>
        <source>Move selection down 1px</source>
        <translation type="vanished">Kijelölés mozgatása le 1px-el</translation>
    </message>
    <message>
        <source>Quit capture</source>
        <translation>Felvétel bezárása</translation>
    </message>
    <message>
        <source>Screenshot history</source>
        <translation>Képernyőmentési előzmények</translation>
    </message>
    <message>
        <source>Capture screen</source>
        <translation>Képernyő rögzítése</translation>
    </message>
    <message>
        <source>Show color picker</source>
        <translation>Színválasztó mutatása</translation>
    </message>
    <message>
        <source>Change the tool&apos;s thickness</source>
        <translation type="vanished">Eszköz vonalvastagságának állítása</translation>
    </message>
    <message>
        <source>Save screenshot</source>
        <translation>Képernyőkép mentése</translation>
    </message>
    <message>
        <source>Capture is saved and copied to the clipboard as </source>
        <translation type="vanished">A rögzítés mentve és vágolara másolva a következőként </translation>
    </message>
    <message>
        <source>Per default runs Flameshot in the background and adds a tray icon for configuration.</source>
        <translation>A Flameshot alapértelmezés szerint fut a háttérben és ikont helyez el a tálcán a beállítások elérése érdekében.</translation>
    </message>
    <message>
        <source>Print geometry of the selection in the format WxH+X+Y. Does nothing if raw is specified</source>
        <translation>A kijelölés geometriáját írja ki Sz M X Y (Szélesség Magasság X pozíció Y pozíció) formátumban. Nem csinál semmit, hogyha a nyers opció aktív</translation>
    </message>
    <message>
        <source>Select entire screen</source>
        <translation type="vanished">Teljes kijelző kijelölése</translation>
    </message>
    <message>
        <source>Commit text in text area</source>
        <translation type="vanished">Szöveg megadása a szöveg mezőben</translation>
    </message>
    <message>
        <source>Error while saving to clipboard</source>
        <translation>Hiba a vágolapra másolás közben</translation>
    </message>
    <message>
        <source>Delete current tool</source>
        <translation type="vanished">Delete current tool</translation>
    </message>
    <message>
        <source>Saving canceled</source>
        <translation type="vanished">Saving canceled</translation>
    </message>
    <message>
        <source>Save canceled</source>
        <translation type="vanished">Save canceled</translation>
    </message>
    <message>
        <source>Change the tool&apos;s size</source>
        <translation>Change the tool&apos;s size</translation>
    </message>
    <message>
        <source>Full screen screenshot pinned to screen</source>
        <translation>Full screen screenshot pinned to screen</translation>
    </message>
    <message>
        <source>Existing directory or new file to save to</source>
        <translation>Existing directory or new file to save to</translation>
    </message>
    <message>
        <source>Pin the capture to the screen</source>
        <translation>Pin the capture to the screen</translation>
    </message>
    <message>
        <source>Upload screenshot</source>
        <translation>Upload screenshot</translation>
    </message>
    <message>
        <source>Screenshot region to select</source>
        <translation>Screenshot region to select</translation>
    </message>
    <message>
        <source>Accept capture as soon as a selection is made</source>
        <translation>Accept capture as soon as a selection is made</translation>
    </message>
    <message>
        <source>Check the configuration for errors</source>
        <translation>Check the configuration for errors</translation>
    </message>
    <message>
        <source>Define the screen to capture (starting from 0)</source>
        <translation>Define the screen to capture (starting from 0)</translation>
    </message>
    <message>
        <source>Invalid region, use &apos;WxH+X+Y&apos; or &apos;all&apos; or &apos;screen0/screen1/...&apos;.</source>
        <translation>Invalid region, use &apos;WxH+X+Y&apos; or &apos;all&apos; or &apos;screen0/screen1/...&apos;.</translation>
    </message>
    <message>
        <source>Invalid path, must be an existing directory or a new file in an existing directory</source>
        <translation>Invalid path, must be an existing directory or a new file in an existing directory</translation>
    </message>
    <message>
        <source>Path copied to clipboard as </source>
        <translation>Path copied to clipboard as </translation>
    </message>
    <message>
        <source>Invalid delay, it must be a number greater than 0</source>
        <translation>Invalid delay, it must be a number greater than 0</translation>
    </message>
    <message>
        <source>Requested screen exceeds screen count</source>
        <translation>Requested screen exceeds screen count</translation>
    </message>
    <message>
        <source>Repeat screenshot with previously selected region</source>
        <translation>Repeat screenshot with previously selected region</translation>
    </message>
    <message>
        <source>Subcommands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>subcommands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture screenshot of all monitors at the same time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture a screenshot of the specified monitor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable or disable the notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RectangleTool</name>
    <message>
        <source>Rectangle</source>
        <translation>Téglalap</translation>
    </message>
    <message>
        <source>Set the Rectangle as the paint tool</source>
        <translation>Téglalap festőeszköz kiválaszása</translation>
    </message>
</context>
<context>
    <name>RedoTool</name>
    <message>
        <source>Redo</source>
        <translation>Újra</translation>
    </message>
    <message>
        <source>Redo the next modification</source>
        <translation>Következő módosítás újra alkalmazása</translation>
    </message>
</context>
<context>
    <name>SaveTool</name>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Save the capture</source>
        <translation type="vanished">Menti a felvételt</translation>
    </message>
    <message>
        <source>Save screenshot to a file</source>
        <translation>Save screenshot to a file</translation>
    </message>
</context>
<context>
    <name>ScreenGrabber</name>
    <message>
        <source>Unable to capture screen</source>
        <translation>Nem sikerült rögzíteni a kijelzőt</translation>
    </message>
    <message>
        <source>Unable to detect desktop environment (GNOME? KDE? Sway? ...)</source>
        <translation type="vanished">Unable to detect desktop environment (GNOME? KDE? Sway? ...)</translation>
    </message>
    <message>
        <source>Hint: try setting the XDG_CURRENT_DESKTOP environment variable.</source>
        <translation>Hint: try setting the XDG_CURRENT_DESKTOP environment variable.</translation>
    </message>
    <message>
        <source>The universal wayland screen capture adapter requires Grim as the screen capture component of wayland. If the screen capture component is missing, please install it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If the useGrimAdapter setting is not enabled, the dbus protocol will be used. It should be noted that using the dbus protocol under wayland is not recommended. It is recommended to enable the useGrimAdapter setting in flameshot.ini to activate the grim-based general wayland screenshot adapter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>grim&apos;s screenshot component is implemented based on wlroots, it may not be used in GNOME or similar desktop environments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to detect desktop environment (GNOME? KDE? Qile? Sway? ...)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <source>Rectangular Selection</source>
        <translation>Üres téglalap</translation>
    </message>
    <message>
        <source>Set Selection as the paint tool</source>
        <translation>Üres téglalap festőeszköz kiválaszása</translation>
    </message>
</context>
<context>
    <name>SetShortcutDialog</name>
    <message>
        <source>Set Shortcut</source>
        <translation>Gyorsbillentyű beállítása</translation>
    </message>
    <message>
        <source>Enter new shortcut to change </source>
        <translation>Adj meg egy új gyorsbillentyűt a változtatáshoz </translation>
    </message>
    <message>
        <source>Press Esc to cancel or Backspace to disable the keyboard shortcut.</source>
        <translation>Nyomd meg az Esc billentyűt a kilépéshet vagy a Backspace-t a gyorsbillentyűk kikapcsolásához.</translation>
    </message>
    <message>
        <source>Press Esc to cancel or ⌘+Backspace to disable the keyboard shortcut.</source>
        <translation>Press Esc to cancel or ⌘+Backspace to disable the keyboard shortcut.</translation>
    </message>
    <message>
        <source>Flameshot must be restarted for changes to take effect.</source>
        <translation>Flameshot must be restarted for changes to take effect.</translation>
    </message>
</context>
<context>
    <name>ShortcutsWidget</name>
    <message>
        <source>Hot Keys</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <source>Available shortcuts in the screen capture mode.</source>
        <translation>Képernyőfelvétel módban elérhető gyorsbillentyűk.</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Billentyű kombináció</translation>
    </message>
    <message>
        <source>Left Double-click</source>
        <translation></translation>
    </message>
    <message>
        <source>Toggle side panel</source>
        <translation type="unfinished">Oldalsó panel ki- és bekapcsolása</translation>
    </message>
    <message>
        <source>Resize selection left 1px</source>
        <translation type="unfinished">Kijelölés átméretezése balra 1px-el</translation>
    </message>
    <message>
        <source>Resize selection right 1px</source>
        <translation type="unfinished">Kijelölés átméretezése jobbra 1px-el</translation>
    </message>
    <message>
        <source>Resize selection up 1px</source>
        <translation type="unfinished">Kijelölés átméretezése fel 1px-el</translation>
    </message>
    <message>
        <source>Resize selection down 1px</source>
        <translation type="unfinished">Kijelölés átméretezése le 1px-el</translation>
    </message>
    <message>
        <source>Select entire screen</source>
        <translation type="unfinished">Teljes kijelző kijelölése</translation>
    </message>
    <message>
        <source>Move selection left 1px</source>
        <translation type="unfinished">Kijelölés mozgatása balra 1px-el</translation>
    </message>
    <message>
        <source>Move selection right 1px</source>
        <translation type="unfinished">Kijelölés mozgatása jobbra 1px-el</translation>
    </message>
    <message>
        <source>Move selection up 1px</source>
        <translation type="unfinished">Kijelölés mozgatása fel 1px-el</translation>
    </message>
    <message>
        <source>Move selection down 1px</source>
        <translation type="unfinished">Kijelölés mozgatása le 1px-el</translation>
    </message>
    <message>
        <source>Commit text in text area</source>
        <translation type="unfinished">Szöveg megadása a szöveg mezőben</translation>
    </message>
    <message>
        <source>Delete current tool</source>
        <translation type="obsolete">Delete current tool</translation>
    </message>
    <message>
        <source>Capture screen</source>
        <translation type="unfinished">Képernyő rögzítése</translation>
    </message>
    <message>
        <source>Screenshot history</source>
        <translation type="unfinished">Képernyőmentési előzmények</translation>
    </message>
    <message>
        <source>Symmetrically decrease width by 2px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Symmetrically increase width by 2px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Symmetrically increase height by 2px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Symmetrically decrease height by 2px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete selected drawn object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel current selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SidePanelWidget</name>
    <message>
        <source>Active thickness:</source>
        <translation type="vanished">Aktív vastagság:</translation>
    </message>
    <message>
        <source>Active color:</source>
        <translation type="vanished">Aktív szín:</translation>
    </message>
    <message>
        <source>Press ESC to cancel</source>
        <translation type="vanished">Nyomd meg az ESC-et a kilépéshez</translation>
    </message>
    <message>
        <source>Grab Color</source>
        <translation>Szín választása</translation>
    </message>
    <message>
        <source>Active tool size: </source>
        <translation>Active tool size: </translation>
    </message>
    <message>
        <source>Active Color: </source>
        <translation>Active Color: </translation>
    </message>
    <message>
        <source>Display grid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SizeDecreaseTool</name>
    <message>
        <source>Decrease Tool Size</source>
        <translation>Decrease Tool Size</translation>
    </message>
    <message>
        <source>Decrease the size of the other tools</source>
        <translation>Decrease the size of the other tools</translation>
    </message>
</context>
<context>
    <name>SizeIncreaseTool</name>
    <message>
        <source>Increase Tool Size</source>
        <translation>Increase Tool Size</translation>
    </message>
    <message>
        <source>Increase the size of the other tools</source>
        <translation>Increase the size of the other tools</translation>
    </message>
</context>
<context>
    <name>SizeIndicatorTool</name>
    <message>
        <source>Selection Size Indicator</source>
        <translation type="vanished">Kiválaszás Méretének Jelzése</translation>
    </message>
    <message>
        <source>Show the dimensions of the selection (X Y)</source>
        <translation type="vanished">Mutatja a kijelölés pozícióját (X Y)</translation>
    </message>
    <message>
        <source>Show X and Y dimensions of the selection</source>
        <translation type="vanished">Show X and Y dimensions of the selection</translation>
    </message>
</context>
<context>
    <name>StrftimeChooserWidget</name>
    <message>
        <source>Century (00-99)</source>
        <translation>Század (00-99)</translation>
    </message>
    <message>
        <source>Year (00-99)</source>
        <translation>Év (00-99)</translation>
    </message>
    <message>
        <source>Year (2000)</source>
        <translation>Év (2000)</translation>
    </message>
    <message>
        <source>Month Name (jan)</source>
        <translation>Hónapnév (jan)</translation>
    </message>
    <message>
        <source>Month Name (january)</source>
        <translation>Hónapnév (január)</translation>
    </message>
    <message>
        <source>Month (01-12)</source>
        <translation>Hónap (01-12)</translation>
    </message>
    <message>
        <source>Week Day (1-7)</source>
        <translation>Hét napja (1-7)</translation>
    </message>
    <message>
        <source>Week (01-53)</source>
        <translation>Hét (01-53)</translation>
    </message>
    <message>
        <source>Day Name (mon)</source>
        <translation>Nap neve (Csüt)</translation>
    </message>
    <message>
        <source>Day Name (monday)</source>
        <translation>Nap neve (Csütörtök)</translation>
    </message>
    <message>
        <source>Day (01-31)</source>
        <translation>Nap (01-31)</translation>
    </message>
    <message>
        <source>Day of Month (1-31)</source>
        <translation>Nap a hónapban (1-31)</translation>
    </message>
    <message>
        <source>Day (001-366)</source>
        <translation>Nap (001-366)</translation>
    </message>
    <message>
        <source>Time (%H:%M:%S)</source>
        <translation type="vanished">Idő (%H:%M:%S)</translation>
    </message>
    <message>
        <source>Time (%H:%M)</source>
        <translation type="vanished">Idő (%H:%M)</translation>
    </message>
    <message>
        <source>Hour (00-23)</source>
        <translation>Óra (00-23)</translation>
    </message>
    <message>
        <source>Hour (01-12)</source>
        <translation>Óra (01-12)</translation>
    </message>
    <message>
        <source>Minute (00-59)</source>
        <translation>Perc (00-59)</translation>
    </message>
    <message>
        <source>Second (00-59)</source>
        <translation>Másodperc (00-59)</translation>
    </message>
    <message>
        <source>Full Date (%m/%d/%y)</source>
        <translation>Teljes dátum (%m/%d/%y)</translation>
    </message>
    <message>
        <source>Full Date (%Y-%m-%d)</source>
        <translation>Teljes dátum (%Y-%m-%d)</translation>
    </message>
    <message>
        <source>Time (%H-%M-%S)</source>
        <translation>Idő (%H-%M-%S)</translation>
    </message>
    <message>
        <source>Time (%H-%M)</source>
        <translation>Idő (%H-%M)</translation>
    </message>
</context>
<context>
    <name>SystemNotification</name>
    <message>
        <source>Flameshot Info</source>
        <translation>A Flameshot-ról</translation>
    </message>
</context>
<context>
    <name>TextConfig</name>
    <message>
        <source>StrikeOut</source>
        <translation>Áthúzott</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Aláhúzott</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Félkövér</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Dőlt</translation>
    </message>
    <message>
        <source>Left Align</source>
        <translation>Left Align</translation>
    </message>
    <message>
        <source>Center Align</source>
        <translation>Center Align</translation>
    </message>
    <message>
        <source>Right Align</source>
        <translation>Right Align</translation>
    </message>
</context>
<context>
    <name>TextTool</name>
    <message>
        <source>Text</source>
        <translation>Szöveg</translation>
    </message>
    <message>
        <source>Add text to your capture</source>
        <translation>Adj szöveget a rögzítéshez</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>&amp;Take Screenshot</source>
        <translation type="unfinished">&amp;Képernyő Mentés Készítése</translation>
    </message>
    <message>
        <source>&amp;Open Launcher</source>
        <translation type="unfinished">&amp;Alkalmazásindító Megnyitása</translation>
    </message>
    <message>
        <source>&amp;Configuration</source>
        <translation type="unfinished">&amp;Konfiguráció</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;Rólunk</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation type="unfinished">Frissítések keresése</translation>
    </message>
    <message>
        <source>New version %1 is available</source>
        <translation type="unfinished">Elérhető az új %1 verzió</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Bezárás</translation>
    </message>
    <message>
        <source>&amp;Latest Uploads</source>
        <translation type="unfinished">&amp;Eddigi Feltöltések</translation>
    </message>
    <message>
        <source>&amp;Open Save Path</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIcolorEditor</name>
    <message>
        <source>UI Color Editor</source>
        <translation type="vanished">Kezelőfelület Színeinek Szerkesztése</translation>
    </message>
    <message>
        <source>Change the color moving the selectors and see the changes in the preview buttons.</source>
        <translation>Válassz színt az egér mozgatásával és nézd ahogy változnak az előnézeti gombok.</translation>
    </message>
    <message>
        <source>Select a Button to modify it</source>
        <translation>Válassz gombot a módosításához</translation>
    </message>
    <message>
        <source>Main Color</source>
        <translation>Fő Szín</translation>
    </message>
    <message>
        <source>Click on this button to set the edition mode of the main color.</source>
        <translation>Kattints a gombra hogy beállítsd a szerkesztő módját a fő színnek.</translation>
    </message>
    <message>
        <source>Contrast Color</source>
        <translation>Kiemelő Szín</translation>
    </message>
    <message>
        <source>Click on this button to set the edition mode of the contrast color.</source>
        <translation>Kattints erre a gombra hogy beállítsd a szerkesztő módját a kiemelő színnek.</translation>
    </message>
</context>
<context>
    <name>UndoTool</name>
    <message>
        <source>Undo</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <source>Undo the last modification</source>
        <translation>Visszavonja az utolsó módosítást</translation>
    </message>
</context>
<context>
    <name>UpdateNotificationWidget</name>
    <message>
        <source>New Flameshot version %1 is available</source>
        <translation>Elérhető az új %1 Flameshot verzió</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Mellőzés</translation>
    </message>
    <message>
        <source>Later</source>
        <translation>Később</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Frissítés</translation>
    </message>
</context>
<context>
    <name>UploadHistory</name>
    <message>
        <source>Upload History</source>
        <translation>Upload History</translation>
    </message>
    <message>
        <source>Screenshots history is empty</source>
        <translation type="unfinished">Nincs korábbi képernyőmentésed</translation>
    </message>
</context>
<context>
    <name>UploadLineItem</name>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <source>Copy URL</source>
        <translation type="unfinished">URL másolása</translation>
    </message>
    <message>
        <source>Open In Browser</source>
        <translation>Open In Browser</translation>
    </message>
    <message>
        <source>Confirm to delete</source>
        <translation type="unfinished">Törlés megerősítése</translation>
    </message>
    <message>
        <source>Are you sure you want to delete a screenshot from the latest uploads and server?</source>
        <translation type="unfinished">Biztosan törölni szeretnéd a képernyőmentést a korábbi feltöltések közül és a szerverről is?</translation>
    </message>
</context>
<context>
    <name>UtilityPanel</name>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>&lt;Empty&gt;</source>
        <translation>&lt;Empty&gt;</translation>
    </message>
</context>
<context>
    <name>VisualsEditor</name>
    <message>
        <source>Opacity of area outside selection:</source>
        <translation>A kijelölésen kívüli terület átlátszósága:</translation>
    </message>
    <message>
        <source>Button Selection</source>
        <translation>Gomb választás</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Összes kiválasztása</translation>
    </message>
    <message>
        <source>UI Color Editor</source>
        <translation type="unfinished">Kezelőfelület Színeinek Szerkesztése</translation>
    </message>
    <message>
        <source>Colorpicker Editor</source>
        <translation>Colorpicker Editor</translation>
    </message>
</context>
<context>
    <name>color_widgets::ColorDialog</name>
    <message>
        <source>Pick</source>
        <translation>Pick</translation>
    </message>
</context>
<context>
    <name>color_widgets::ColorPalette</name>
    <message>
        <source>Unnamed</source>
        <translation>Unnamed</translation>
    </message>
</context>
<context>
    <name>color_widgets::ColorPaletteModel</name>
    <message>
        <source>Unnamed</source>
        <translation>Unnamed</translation>
    </message>
    <message>
        <source>%1 (%2 colors)</source>
        <translation>%1 (%2 colors)</translation>
    </message>
</context>
<context>
    <name>color_widgets::ColorPaletteWidget</name>
    <message>
        <source>Open a new palette from file</source>
        <translation>Open a new palette from file</translation>
    </message>
    <message>
        <source>Create a new palette</source>
        <translation>Create a new palette</translation>
    </message>
    <message>
        <source>Duplicate the current palette</source>
        <translation>Duplicate the current palette</translation>
    </message>
    <message>
        <source>Delete the current palette</source>
        <translation>Delete the current palette</translation>
    </message>
    <message>
        <source>Revert changes to the current palette</source>
        <translation>Revert changes to the current palette</translation>
    </message>
    <message>
        <source>Save changes to the current palette</source>
        <translation>Save changes to the current palette</translation>
    </message>
    <message>
        <source>Add a color to the palette</source>
        <translation>Add a color to the palette</translation>
    </message>
    <message>
        <source>Remove the selected color from the palette</source>
        <translation>Remove the selected color from the palette</translation>
    </message>
    <message>
        <source>New Palette</source>
        <translation>New Palette</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>GIMP Palettes (*.gpl)</source>
        <translation>GIMP Palettes (*.gpl)</translation>
    </message>
    <message>
        <source>Palette Image (%1)</source>
        <translation>Palette Image (%1)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>All Files (*)</translation>
    </message>
    <message>
        <source>Open Palette</source>
        <translation>Open Palette</translation>
    </message>
    <message>
        <source>Failed to load the palette file
%1</source>
        <translation>Failed to load the palette file
%1</translation>
    </message>
</context>
<context>
    <name>color_widgets::GradientEditor</name>
    <message>
        <source>Add Color</source>
        <translation>Add Color</translation>
    </message>
    <message>
        <source>Remove Color</source>
        <translation>Remove Color</translation>
    </message>
    <message>
        <source>Edit Color...</source>
        <translation>Edit Color...</translation>
    </message>
</context>
<context>
    <name>color_widgets::GradientListModel</name>
    <message>
        <source>%1 (%2 colors)</source>
        <translation>%1 (%2 colors)</translation>
    </message>
</context>
<context>
    <name>color_widgets::Swatch</name>
    <message>
        <source>Clear Color</source>
        <translation>Clear Color</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
</context>
</TS>
